OC.L10N.register(
    "deck",
    {
    "You have created a new board {board}" : "您已建立新的佈告欄 {board}",
    "{user} has created a new board {board}" : "{user} 已建立新的佈告欄 {board}",
    "You have deleted the board {board}" : "您已刪除佈告欄 {board}",
    "{user} has deleted the board {board}" : "{user} 已刪除佈告欄 {board}",
    "You have restored the board {board}" : "您已還原佈告欄 {board}",
    "{user} has restored the board {board}" : "{user} 已還原佈告欄 {board}",
    "You have shared the board {board} with {acl}" : "您已和 {acl} 分享佈告欄 {board}",
    "{user} has shared the board {board} with {acl}" : "{user} 已和 {acl} 分享佈告欄 {board}",
    "You have removed {acl} from the board {board}" : "您已從佈告欄 {board} 移除 {acl}",
    "{user} has removed {acl} from the board {board}" : "{user} 已從佈告欄 {board} 移除 {acl}",
    "You have renamed the board {before} to {board}" : "您已將佈告欄 {before} 重新命名為 {board}",
    "{user} has renamed the board {before} to {board}" : "{user} 已將佈告欄 {before} 重新命名為 {board}",
    "You have archived the board {board}" : "您已封存佈告欄 {board}",
    "{user} has archived the board {before}" : "{user} 已封存佈告欄 {before}",
    "You have unarchived the board {board}" : "您已解除封存佈告欄 {board}",
    "{user} has unarchived the board {before}" : "{user} 已解除封存佈告欄 {before}",
    "You have created a new list {stack} on board {board}" : "您已在佈告欄 {board} 上建立新列表 {stack}",
    "{user} has created a new list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上建立新列表 {stack}",
    "You have renamed list {before} to {stack} on board {board}" : "您已將佈告欄 {board} 上的列表 {before} 重新命名為 {stack}",
    "{user} has renamed list {before} to {stack} on board {board}" : "{user} 已將佈告欄 {board} 上的列表 {before} 重新命名為 {stack}",
    "You have deleted list {stack} on board {board}" : "您已刪除佈告欄 {board} 上的列表 {stack}",
    "{user} has deleted list {stack} on board {board}" : "{user} 已刪除佈告欄 {board} 上的列表 {stack}",
    "You have created card {card} in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 建立卡片 {card}",
    "{user} has created card {card} in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 建立卡片 {card}",
    "You have deleted card {card} in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 刪除卡片 {card}",
    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 刪除卡片 {card}",
    "You have renamed the card {before} to {card}" : "您已將卡片 {before} 重新命名為 {card}",
    "{user} has renamed the card {before} to {card}" : "{user} 已將卡片 {before} 重新命名為 {card}",
    "You have added a description to card {card} in list {stack} on board {board}" : "您已將描述新增到佈告欄 {board} 上的列表 {stack} 的卡片 {card}",
    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} 已將描述新增到佈告欄 {board} 上的列表 {stack} 的卡片 {card}",
    "You have updated the description of card {card} in list {stack} on board {board}" : "您已更新佈告欄 {board} 上的列表 {stack} 的卡片 {card} 的描述",
    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} 已更新佈告欄 {board} 上的列表 {stack} 的卡片 {card} 的描述",
    "You have archived card {card} in list {stack} on board {board}" : "您已封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
    "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
    "You have unarchived card {card} in list {stack} on board {board}" : "您已解除封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已解除封存佈告欄 {board} 上的列表 {stack} 中的卡片 {card}",
    "You have marked the card {card} as done in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為已完成",
    "You have marked the card {card} as undone in list {stack} on board {board}" : "您已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} 已在佈告欄 {board} 上的列表 {stack} 標記卡片 {card} 為未完成",
    "You have removed the due date of card {card}" : "您已移除卡片 {card} 的到期日",
    "{user} has removed the due date of card {card}" : "{user} 已移除卡片 {card} 的到期日",
    "You have set the due date of card {card} to {after}" : "您已設定卡片 {card} 的到期日",
    "{user} has set the due date of card {card} to {after}" : "{user} 已設定卡片 {card} 的到期日",
    "You have updated the due date of card {card} to {after}" : "您已將卡片 {card} 的到期日更新為 {after}",
    "{user} has updated the due date of card {card} to {after}" : "{user} 已將卡片 {card} 的到期日更新為 {after}",
    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "您已將標籤 {label} 新增到佈告欄 {board} 上的列表 {stack} 的卡片 {card}",
    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} 已將標籤 {label} 新增到佈告欄 {board} 上的列表 {stack} 的卡片 {card}",
    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "您已將標籤 {label} 從佈告欄 {board} 上列表 {stack} 中的卡片 {card} 移除",
    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} 已將標籤 {label} 從佈告欄 {board} 上列表 {stack} 中的卡片 {card} 移除",
    "You have assigned {assigneduser} to card {card} on board {board}" : "您已將佈告欄 {board} 上的卡片 {card} 分配給 {assigneduser}",
    "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} 已將佈告欄 {board} 上的卡片 {card} 分配給 {assigneduser}",
    "You have unassigned {assigneduser} from card {card} on board {board}" : "您已取消分配佈告欄 {board} 上的卡片 {card} 給 {assigneduser}",
    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} 已取消分配佈告欄 {board} 上的卡片 {card} 給 {assigneduser}",
    "You have moved the card {card} from list {stackBefore} to {stack}" : "您已將卡片 {card} 從列表 {stackBefore} 移動到 {stack}",
    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} 已將卡片 {card} 從列表 {stackBefore} 移動到 {stack}",
    "You have added the attachment {attachment} to card {card}" : "您已將附件 {attachment} 新增到 {card}",
    "{user} has added the attachment {attachment} to card {card}" : "{user} 已將附件 {attachment} 新增到 {card}",
    "You have updated the attachment {attachment} on card {card}" : "您已更新卡片 {card} 上的附件 {attachment}",
    "{user} has updated the attachment {attachment} on card {card}" : "{user} 已更新卡片 {card} 上的附件 {attachment}",
    "You have deleted the attachment {attachment} from card {card}" : "您已從卡片 {card} 刪除附件 {attachment}",
    "{user} has deleted the attachment {attachment} from card {card}" : "{user} 已從卡片 {card} 刪除附件 {attachment}",
    "You have restored the attachment {attachment} to card {card}" : "您已從卡片 {card} 還原附件 {attachment}",
    "{user} has restored the attachment {attachment} to card {card}" : "{user} 已從卡片 {card} 還原附件 {attachment}",
    "You have commented on card {card}" : "您已在卡片 {card} 上留言",
    "{user} has commented on card {card}" : "{user} 已在卡片 {card} 上留言",
    "Deck" : "Deck",
    "Changes in the <strong>Deck app</strong>" : "<strong>Deck 應用程式</strong>中的變更",
    "A <strong>board, list or card</strong> was changed" : "<strong>佈告欄、清單或卡片</strong>已變更",
    "A <strong>comment</strong> was created on a card" : "已在卡片上建立了<strong>留言</strong>",
    "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已變更",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部份上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法寫入硬碟",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案超過上限 %s",
    "Invalid file type. Only JSON files are allowed." : "無效的檔案類型。僅允許 JSON 檔案。",
    "Invalid JSON data" : "無效的 JSON 資料",
    "Failed to import board" : "匯入看板失敗",
    "Cards due today" : "卡片於今日到期",
    "Cards due tomorrow" : "卡片於明日到期",
    "Upcoming cards" : "接下來的卡片",
    "Load more" : "載入更多",
    "Welcome to Nextcloud Deck!" : "歡迎使用 Nextcloud Deck！",
    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片「%s」位於「%s」已由 %s 分配給您。",
    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將位於 {deck-board} 的 {deck-card} 卡片分配給您。",
    "The card \"%1$s\" on \"%2$s\" has reached its due date." : "在「%2$s」上的卡片「%1$s」已達到期日。",
    "The card {deck-card} on {deck-board} has reached its due date." : "位於 {deck-board} 的 {deck-card} 卡片已達其到期日。",
    "%s has mentioned you in a comment on \"%s\"." : "%s 在「%s」的留言中提到了您。",
    "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的留言中提及您。",
    "The board \"%s\" has been shared with you by %s." : "佈告欄「%s」已由 %s 分享給您。",
    "{user} has shared {deck-board} with you." : "{user} 已與您分享 {deck-board}。",
    "Deck board" : "Deck 佈告欄",
    "Owned by %1$s" : "由 %1$s 擁有",
    "Deck boards, cards and comments" : "Deck 看板、卡片與評論",
    "From %1$s, in %2$s/%3$s, owned by %4$s" : "來自 %1$s，在 %2$s/%3$s，由 %4$s 擁有",
    "Create a new deck card" : "建立新 deck 卡片",
    "Card comments" : "卡片留言",
    "%s on %s" : "%s 在 %s",
    "Deck boards and cards" : "Deck 看板與卡片",
    "No data was provided to create an attachment." : "沒有提供用於建立附件的資料。",
    "Finished" : "已完成",
    "To review" : "待檢閱",
    "Action needed" : "需要採取行動",
    "Later" : "稍後",
    "copy" : "複製",
    "Read more inside" : "深入閱讀",
    "Custom lists - click to rename!" : "自訂清單 - 點選以重新命名！",
    "To Do" : "待辦",
    "In Progress" : "進行中",
    "Done" : "完成",
    "1. Open to learn more about boards and cards" : "1. 開啟以取得更多關於看板與卡片的資訊",
    "2. Drag cards left and right, up and down" : "2. 將卡片向左、向右、向上或向下拖曳",
    "3. Apply rich formatting and link content" : "3. 套用豐富格式與連結內容",
    "4. Share, comment and collaborate!" : "4. 分享、留言與協作！",
    "Create your first card!" : "建立您的第一張卡片！",
    "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此評論多於 %s 個字元。\n作為附件新增至名為 %s 的卡片上。\n可於此 URL 存取：%s。",
    "Attachments" : "附件",
    "File" : "檔案",
    "date" : "日期",
    "Card not found" : "找不到卡片",
    "Path is already shared with this card" : "路徑已與此卡片分享",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，日期格式必須為 YYYY-MM-DD",
    "Personal planning and team project organization" : "個人規劃與團隊專案組織",
    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
    "Add board" : "新增佈告欄",
    "Card details" : "卡片詳細資訊",
    "Select the board to link to a project" : "選取要連結到專案的佈告欄",
    "Search by board title" : "按佈告欄標題搜尋",
    "Select board" : "選取佈告欄",
    "Move/copy card" : "移動/複製卡片",
    "Select a board" : "選取佈告欄",
    "No lists available" : "沒有可用的列表",
    "Select a list" : "選取列表",
    "Move card" : "移動卡片",
    "Copy card" : "複製卡片",
    "Select the card to link to a project" : "選取要連結到專案的卡片",
    "Link to card" : "連結到卡片",
    "Select a card" : "選取卡片",
    "Cancel" : "取消",
    "This board is read only" : "此佈告欄唯讀",
    "Drop your files to upload" : "拖曳您的檔案以上傳",
    "File already exists" : "檔案已存在",
    "A file with the name {filename} already exists." : "名稱為 {filename} 的檔案已存在。",
    "Do you want to overwrite it?" : "您想要覆寫它嗎？",
    "Overwrite file" : "覆寫檔案",
    "Keep existing file" : "保留既有檔案",
    "Add card" : "新增卡片",
    "Archived cards" : "已封存的卡片",
    "Add list" : "新增列表",
    "List name" : "列表名稱",
    "Active filters" : "作用中的過濾條件",
    "Apply filter" : "套用過濾條件",
    "Filter by tag" : "按標籤過濾",
    "Filter by assigned user" : "按被分配的使用者過濾",
    "Unassigned" : "未分配",
    "Filter by status" : "以狀態過濾",
    "Open and completed" : "開啟並完成",
    "Open" : "開啟",
    "Completed" : "已完成",
    "Filter by due date" : "按到期日過濾",
    "Overdue" : "超過到期日",
    "Next 24 hours" : "接下來24小時",
    "Next 7 days" : "接下來7天",
    "Next 30 days" : "接下來30天",
    "No due date" : "無到期日",
    "Clear filter" : "清除過濾條件",
    "View Modes" : "檢視模式",
    "Toggle View Modes" : "切換檢視模式",
    "Hide archived cards" : "隱藏已封存的卡片",
    "Show archived cards" : "顯示已封存的卡片",
    "Toggle compact mode" : "切換簡潔模式",
    "Hide card cover images" : "隱藏卡片封面影像",
    "Show card cover images" : "顯示卡片封面影像",
    "Open details" : "開啟細節",
    "Details" : "詳細資料",
    "Deck settings" : "Deck 設定",
    "General" : "一般",
    "Use bigger card view" : "使用較大的卡片檢視",
    "Appearance" : "外觀",
    "Show card ID badge" : "顯示卡片 ID 徽章",
    "Show boards in calendar/tasks" : "在日曆／工作項目中顯示佈告欄",
    "Admin settings" : "管理員設定",
    "Limit board creation to some groups" : "限制僅某些群組可建立看板",
    "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
    "Board actions" : "看板動作",
    "Scroll sideways" : "橫向捲軸",
    "Navigate between cards" : "在卡片間移動",
    "Close card details" : "關閉卡片詳細資訊",
    "Search" : "搜尋",
    "Show card filters" : "顯示卡片篩選條件",
    "Clear card filters" : "清除卡片篩選條件",
    "Show those shortcuts" : "顯示這些快捷鍵",
    "Card actions" : "卡片動作",
    "Open card details" : "開啟卡片詳細資訊",
    "Edit the card title" : "編輯卡片標題",
    "Assign yourself to the current card" : "將自己指派給目前的卡片",
    "Archive/unarchive the current card" : "封存/解除封存目前卡片",
    "Mark card as completed/not completed" : "將卡片標記為完成/未完成",
    "Open card menu" : "開啟卡片選單",
    "Currently present people" : "目前在場夥伴",
    "Loading board" : "正在載入佈告欄",
    "Board not found" : "找不到佈告欄",
    "Create a new list to add cards to this board" : "建立新列表以新增卡片到此佈告欄",
    "Sharing" : "分享",
    "Tags" : "標籤",
    "Deleted items" : "刪除的項目",
    "Activity" : "活動",
    "Deleted lists" : "已刪除的列表",
    "Undo" : "復原",
    "Deleted cards" : "已刪除的卡片",
    "Failed to create share with {displayName}" : "無法建立與 {displayName} 的分享",
    "Are you sure you want to transfer the board {title} to {user}?" : "您確定您想要將看板 {title} 轉移給 {user} 嗎？",
    "Transfer the board." : "轉移看板。",
    "Transfer" : "轉移",
    "The board has been transferred to {user}" : "看板已轉移給 {user}",
    "Failed to transfer the board to {user}" : "轉移看板給 {user} 失敗",
    "Share board with a user, group or team …" : "與使用者、群組或團隊分享佈告欄……",
    "Searching for users, groups and teams …" : "搜尋使用者、群組與團隊……",
    "No participants found" : "找不到參與者",
    "Board owner" : "佈告欄擁有者",
    "(Group)" : "（群組）",
    "(Team)" : "（團隊）",
    "Can edit" : "可以編輯",
    "Can share" : "可以分享",
    "Can manage" : "可以管理",
    "Owner" : "擁有者",
    "Delete" : "刪除",
    "List deleted" : "列表已刪除",
    "Edit list title" : "編輯清單標題",
    "Archive all cards" : "封存所有卡片",
    "Unarchive all cards" : "解除封存所有卡片",
    "Delete list" : "刪除列表",
    "Archive all cards in this list" : "封存此列表中的所有卡片",
    "Unarchive all cards in this list" : "解除封存所有此列表中的卡片",
    "Add a new card" : "新增卡片",
    "Card name" : "卡片名稱",
    "title and color value must be provided" : "必須提供標題與顏色的值",
    "Edit" : "編輯",
    "Add a new tag" : "新增標籤",
    "Board name" : "佈告欄名稱",
    "Members" : "成員",
    "Assign to users/groups/team" : "分配給使用者／群組／團隊",
    "Assign a user to this card…" : "分配使用者到此卡片……",
    "Select a user to assign to this card…" : "選取要分配至此卡片的使用者……",
    "File to share" : "要分享的檔案",
    "Invalid path selected" : "選取的路徑無效",
    "Upload new files" : "上傳新檔案",
    "Share from Files" : "從「檔案」分享",
    "Pending share" : "待分享",
    "Add this attachment" : "新增此附件",
    "Show in Files" : "在「檔案」中顯示",
    "Download" : "下載",
    "Remove attachment" : "移除附件",
    "Delete Attachment" : "刪除附件",
    "Restore Attachment" : "還原附件",
    "Modified" : "已修改",
    "Created" : "已新增",
    "The title cannot be empty." : "標題不能為空",
    "Cannot close unsaved card!" : "無法關閉無法儲存的卡片！",
    "Open in sidebar view" : "在側邊欄中開啟",
    "Open in bigger view" : "以較大的檢視模式開啟",
    "Comments" : "留言",
    "Failed to load comments" : "載入留言失敗",
    "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
    "The comment cannot be empty." : "留言不能為空。",
    "The comment cannot be longer than 1000 characters." : "留言不能多於 1000 個字元。",
    "Save" : "儲存",
    "Created:" : "建立：",
    "In reply to" : "回覆",
    "Cancel reply" : "取消回覆",
    "Reply" : "回覆",
    "Update" : "更新",
    "Write a description …" : "編寫描述……",
    "Could not save description" : "無法儲存描述",
    "Description" : "描述",
    "(Unsaved)" : "（未儲存）",
    "(Saving…)" : "（正在儲存……）",
    "Formatting help" : "格式化說明",
    "Edit description" : "編輯描述",
    "View description" : "檢視描述",
    "Add Attachment" : "新增附件",
    "Choose attachment" : "選擇附件",
    "Select Date" : "選擇日期",
    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
    "Set due date for later today" : "設定今天稍後的到期日",
    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
    "Set due date for tomorrow" : "設定明天的到期日",
    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
    "Set due date for this weekend" : "設定本週末的到期日",
    "Next week – {timeLocale}" : "下週 – {timeLocale}",
    "Set due date for next week" : "設定下週的到期日",
    "Assign a due date to this card…" : "為此卡片指派到期日……",
    "Set a due date" : "設定到期日",
    "Add due date" : "新增到期日",
    "Choose a date" : "選擇日期",
    "Remove due date" : "移除到期日",
    "Mark as done" : "標記為完成",
    "Due at:" : "到期於：",
    "Not done" : "未完成",
    "Unarchive card" : "解除封存卡片",
    "Archive card" : "封存卡片",
    "Assign a tag to this card…" : "分配標籤到此卡片……",
    "Select or create a tag…" : "選取或建立標籤……",
    "Create a new tag:" : "建立新標籤：",
    "(group)" : "（群組）",
    "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
    "Todo items" : "待辦事項",
    "Edit card title" : "編輯卡片標題",
    "Open link" : "開啟連結",
    "Card deleted" : "卡片已刪除",
    "Edit title" : "編輯標題",
    "Assign to me" : "分配給我",
    "Unassign myself" : "取消分配給我",
    "Mark as not done" : "標記為未完成",
    "Delete card" : "刪除卡片",
    "seconds ago" : "幾秒前",
    "All boards" : "所有佈告欄",
    "Archived boards" : "已封存的佈告欄",
    "Shared with you" : "與您分享",
    "Cancel edit" : "取消編輯",
    "Save board" : "儲存佈告欄",
    "Board {0} deleted" : "已刪除佈告欄 {0}",
    "All cards" : "所有看片",
    "Only assigned cards" : "僅已分配的卡片",
    "No reminder" : "無提醒",
    "An error occurred" : "發生錯誤",
    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
    "Delete the board?" : "刪除佈告欄？",
    "Exporting board..." : "正在匯出看板……",
    "Board details" : "佈告欄詳細資訊",
    "Edit board" : "編輯佈告欄",
    "Clone board" : "再製佈告欄",
    "Unarchive board" : "解除封存佈告欄",
    "Archive board" : "封存佈告欄",
    "Export board" : "匯出看板",
    "Turn on due date reminders" : "開啟到期日提醒",
    "Turn off due date reminders" : "關閉到期日提醒",
    "Due date reminders" : "到期日提醒",
    "Assigned cards" : "已分配的卡片",
    "No notifications" : "無通知",
    "Delete board" : "刪除佈告欄",
    "Importing board..." : "正在匯入看板……",
    "Board imported successfully" : "已成功匯入看板",
    "Import board" : "匯入看板",
    "Clone {boardTitle}" : "再製 {boardTitle}",
    "Clone cards" : "複製卡片",
    "Clone assignments" : "再製工作",
    "Clone labels" : "再製標籤",
    "Clone due dates" : "再製截止日",
    "Advanced options" : "進階選項",
    "Move all cards to the first list" : "將所有卡片移動到第一個清單",
    "Restore archived cards" : "還原已封存的卡片",
    "Clone" : "複製",
    "Export {boardTitle}" : "匯出 {boardTitle}",
    "Export as JSON" : "匯出為 JSON",
    "Export as CSV" : "匯出為 CSV",
    "Note: Only the JSON format is supported for importing back into the Deck app." : "注意：匯入回 Deck 應用程式時僅支援 JSON 格式。",
    "Export" : "匯出",
    "Loading filtered view" : "正在載入過濾的檢視",
    "Search for {searchQuery} in other boards" : "在其他看板中搜尋 {searchQuery}",
    "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
    "No results found" : "找不到結果",
    "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
    "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 建立於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
    "{nbCards} cards" : "{nbCards} 張卡片",
    "Due on {date}" : "於 {date} 到期",
    "{stack} in {board}" : "{stack} 於 {board}",
    "Click to expand description" : "點擊展開描述",
    "Click to expand comment" : "點擊展開留言",
    "Create card" : "建立卡片",
    "Create a new card" : "建立新卡片",
    "Card title" : "卡片標題",
    "Creating the new card …" : "正在建立新卡片……",
    "Card \"{card}\" was added to \"{board}\"" : "卡片「{card}」已新增至「{board}」",
    "Open card" : "開啟卡片",
    "Close" : "關閉",
    "No upcoming cards" : "無接下來的卡片",
    "upcoming cards today" : "今天接下來的卡片",
    "upcoming cards tomorrow" : "明天接下來的卡片",
    "upcoming cards" : "接下來的卡片",
    "New card" : "新卡片",
    "Link to a board" : "連結到佈告欄",
    "Link to a card" : "連結到卡片",
    "Create a card" : "建立卡片",
    "Message from {author} in {conversationName}" : "來自 {conversationName} 中 {author} 的訊息",
    "Something went wrong" : "出了點問題",
    "Failed to upload {name}" : "上傳 {name} 失敗",
    "Maximum file size of {size} exceeded" : "超過最大的檔案大小 {size} ",
    "Assigned users" : "已分派的使用者 ",
    "Due date" : "到期日",
    "Error creating the share" : "建立分享時發生錯誤",
    "Share with a Deck card" : "與 Deck 卡片分享",
    "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
    "Share" : "分享",
    "Personal" : "個人",
    "The card \"%s\" on \"%s\" has reached its due date." : "卡片「%s」位於「%s」已達到期日。",
    "To do" : "待辦事項",
    "Doing" : "正在進行",
    "Example Task 3" : "範例工作 3",
    "Example Task 2" : "範例工作 2",
    "Example Task 1" : "範例工作 1",
    "Keyboard shortcuts" : "鍵盤快速鍵",
    "Boost your productivity using Deck with keyboard shortcuts." : "在 Deck 上利用鍵盤快捷鍵提高您的生產力。",
    "Keyboard shortcut" : "鍵盤快捷鍵",
    "Action" : "動作",
    "Shift" : "Shift",
    "Scroll" : "捲軸",
    "Esc" : "Esc",
    "Ctrl" : "Ctrl",
    "Show help dialog" : "顯示說明對話方塊",
    "The following actions can be triggered on the currently highlighted card" : "可以在目前突顯的卡片上觸發以下動作",
    "Enter" : "輸入",
    "Space" : "空間",
    "Today" : "今天",
    "Tomorrow" : "明天",
    "No due" : "無到期日"
},
"nplurals=1; plural=0;");
